@@ -1,6 +1,6 @@
 /*
  * Carla common defines
- * Copyright (C) 2011-2022 Filipe Coelho <falktx@falktx.com>
+ * Copyright (C) 2011-2023 Filipe Coelho <falktx@falktx.com>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -32,14 +32,14 @@
 #endif
 
 /* Set Version */
-#define CARLA_VERSION_HEX    0x020402
-#define CARLA_VERSION_STRING "2.4.3"
-#define CARLA_VERSION_STRMIN "2.4"
+#define CARLA_VERSION_HEX    0x020503
+#define CARLA_VERSION_STRING "2.5.3"
+#define CARLA_VERSION_STRMIN "2.5"
 
 /* Check OS */
 #if defined(WIN64) || defined(_WIN64) || defined(__WIN64__) || defined(_M_ARM64)
 # define CARLA_OS_WIN64
-#elif defined(WIN32) || defined(_WIN32) || defined(__WIN32__)
+#elif defined(WIN32) || defined(_WIN32) || defined(__WIN32__) || defined(_M_ARM)
 # define CARLA_OS_WIN32
 #elif defined(__APPLE__)
 # define CARLA_OS_MAC
@@ -51,6 +51,8 @@
 # define CARLA_OS_BSD
 #elif defined(__GNU__)
 # define CARLA_OS_GNU_HURD
+#elif defined(__EMSCRIPTEN__)
+# define CARLA_OS_WASM
 #else
 # warning Unsupported platform!
 #endif
@@ -74,8 +76,8 @@
 # if __cplusplus >= 201103L || (defined(__GNUC__) && (__GNUC__ * 100 + __GNUC_MINOR__) >= 405 && defined(__GXX_EXPERIMENTAL_CXX0X__)) || __has_extension(cxx_noexcept)
 #  define CARLA_PROPER_CPP11_SUPPORT
 #  if (defined(__GNUC__) && (__GNUC__ * 100 + __GNUC_MINOR__) < 407 && ! defined(__clang__)) || (defined(__clang__) && ! __has_extension(cxx_override_control))
-#   define override // gcc4.7+ only
-#   define final    // gcc4.7+ only
+#   define override /* gcc4.7+ only */
+#   define final    /* gcc4.7+ only */
 #  endif
 # endif
 #endif
@@ -110,6 +112,13 @@
 # define P_UINTPTR "%x"
 # define P_SIZE    "%u"
 # define P_SSIZE   "%i"
+#elif defined(CARLA_OS_WASM)
+# define P_INT64   "%lli"
+# define P_UINT64  "%llu"
+# define P_INTPTR  "%li"
+# define P_UINTPTR "%lx"
+# define P_SIZE    "%lu"
+# define P_SSIZE   "%li"
 #elif defined(CARLA_OS_MAC)
 # define P_INT64   "%lli"
 # define P_UINT64  "%llu"
@@ -217,16 +226,16 @@
 #define CARLA_SAFE_EXCEPTION_CONTINUE(msg)    CARLA_CATCH_UNWIND catch(...) { carla_safe_exception(msg, __FILE__, __LINE__); continue; }
 #define CARLA_SAFE_EXCEPTION_RETURN(msg, ret) CARLA_CATCH_UNWIND catch(...) { carla_safe_exception(msg, __FILE__, __LINE__); return ret; }
 
-/* Define CARLA_DECLARE_NON_COPY_CLASS */
+/* Define CARLA_DECLARE_NON_COPYABLE */
 #ifdef CARLA_PROPER_CPP11_SUPPORT
-# define CARLA_DECLARE_NON_COPY_CLASS(ClassName) \
+# define CARLA_DECLARE_NON_COPYABLE(ClassName) \
 private:                                         \
     ClassName(ClassName&) = delete;              \
     ClassName(const ClassName&) = delete;        \
     ClassName& operator=(ClassName&) = delete;   \
     ClassName& operator=(const ClassName&) = delete;
 #else
-# define CARLA_DECLARE_NON_COPY_CLASS(ClassName) \
+# define CARLA_DECLARE_NON_COPYABLE(ClassName) \
 private:                                         \
     ClassName(ClassName&);                       \
     ClassName(const ClassName&);                 \
@@ -234,17 +243,6 @@ private:                                         \
     ClassName& operator=(const ClassName&);
 #endif
 
-/* Define CARLA_DECLARE_NON_COPY_STRUCT */
-#ifdef CARLA_PROPER_CPP11_SUPPORT
-# define CARLA_DECLARE_NON_COPY_STRUCT(StructName) \
-    StructName(StructName&) = delete;              \
-    StructName(const StructName&) = delete;        \
-    StructName& operator=(StructName&) = delete;   \
-    StructName& operator=(const StructName&) = delete;
-#else
-# define CARLA_DECLARE_NON_COPY_STRUCT(StructName)
-#endif
-
 /* Define CARLA_PREVENT_HEAP_ALLOCATION */
 #ifdef CARLA_PROPER_CPP11_SUPPORT
 # define CARLA_PREVENT_HEAP_ALLOCATION \
